from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MsHelperCls:
	"""MsHelper commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("msHelper", core, parent)

	@property
	def conductor(self):
		"""conductor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conductor'):
			from .Conductor import ConductorCls
			self._conductor = ConductorCls(self._core, self._cmd_group)
		return self._conductor

	@property
	def mhelper(self):
		"""mhelper commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mhelper'):
			from .Mhelper import MhelperCls
			self._mhelper = MhelperCls(self._core, self._cmd_group)
		return self._mhelper

	def clone(self) -> 'MsHelperCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MsHelperCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
